@@ -16,6 +16,7 @@ sub is_success {
 sub has_error {
     !$_[0]->is_success;
 }
+*is_error = *has_error;
 
 sub code {
     $_[0]->http_response->code;
@@ -80,6 +81,10 @@ WWW::Google::C2DM::Response is a WWW::Google::C2DM internal class.
 
   $res->is_success ? 1 : 0;
 
+=item is_error()
+
+  $res->is_error ? 1 : 0;
+
 =item has_error()
 
   $res->has_error ? 1 : 0;
